@@ -115,15 +115,19 @@ namespace libtorrent {
 	// this object holds configuration options for limits to use when loading
 	// torrents. They are meant to prevent loading potentially malicious torrents
 	// that cause excessive memory allocations.
-	struct load_torrent_limits
+	struct TORRENT_EXPORT load_torrent_limits
 	{
-		int max_buffer_size = 6000000;
+		// the max size of a .torrent file to load into RAM
+		int max_buffer_size = 10000000;
+
 		// the max number of pieces allowed in the torrent
-		int max_pieces = 0x100000;
+		int max_pieces = 0x200000;
+
 		// the max recursion depth in the bdecoded structure
 		int max_decode_depth = 100;
+
 		// the max number of bdecode tokens
-		int max_decode_tokens = 2000000;
+		int max_decode_tokens = 3000000;
 	};
 
 	// the torrent_info class holds the information found in a .torrent file.
@@ -234,7 +238,7 @@ namespace libtorrent {
 			return m_orig_files ? *m_orig_files : m_files;
 		}
 
-		// Renames a the file with the specified index to the new name. The new
+		// Renames the file with the specified index to the new name. The new
 		// filename is reflected by the ``file_storage`` returned by ``files()``
 		// but not by the one returned by ``orig_files()``.
 		//
@@ -394,8 +398,26 @@ namespace libtorrent {
 		file_iterator file_at_offset(std::int64_t offset) const
 		{ return m_files.file_at_offset_deprecated(offset); }
 
+#ifdef _MSC_VER
+#pragma warning(push, 1)
+// warning C4996: X: was declared deprecated
+#pragma warning( disable : 4996 )
+#endif
+#if defined __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
 		TORRENT_DEPRECATED
 		file_entry file_at(int index) const { return m_files.at_deprecated(index); }
+
+#if defined __GNUC__
+#pragma GCC diagnostic pop
+#endif
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
+
 #endif // TORRENT_ABI_VERSION
 
 		// If you need index-access to files you can use the ``num_files()`` along
@@ -566,10 +588,15 @@ namespace libtorrent {
 			, piece_index_t piece);
 		std::map<int, sha1_hash> build_merkle_list(piece_index_t piece) const;
 
+		// internal
+		void internal_set_creator(string_view const);
+		void internal_set_creation_date(std::time_t);
+		void internal_set_comment(string_view const);
+
 		// returns whether or not this is a merkle torrent.
 		// see `BEP 30`__.
 		//
-		// __ http://bittorrent.org/beps/bep_0030.html
+		// __ https://www.bittorrent.org/beps/bep_0030.html
 		bool is_merkle_torrent() const { return !m_merkle_tree.empty(); }
 
 	private:
